@@ -21,12 +21,6 @@ aembit_nat_OUTPUT=aembit_nat_OUTPUT
 aembit_nat_PREROUTING=aembit_nat_PREROUTING
 aembit_filter_INPUT=aembit_filter_INPUT
 
-# Enable dynamic routing if the hosts were specified.
-dynamic_routing=false
-if [ -n "${AEMBIT_STEERING_ALLOWED_HOSTS}" ]; then
-    dynamic_routing=true
-fi
-
 log() {
     timestamp=$(date '+%Y-%m-%d %H:%M:%S')
     echo "[${timestamp}] $1"
@@ -251,8 +245,8 @@ function redirect_outbound_tcp_traffic_to_ap() {
     # See https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16.
     add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p tcp --destination "${azure_platform_resources_ip}" -j RETURN
 
-    if [ "${dynamic_routing}" = false ]; then
-        # Redirect all new TCP connections to the Agent Proxy if we're not routing dynamically.
+    if [ -z "${AEMBIT_STEERING_ALLOWED_HOSTS}" ]; then
+        # Redirect all new TCP connections to the Agent Proxy if we didn't specify custom steering.
         #
         # We use the "--syn" flag to forward new connections only, since,
         # prior to adding NAT rules, conntrack is not loaded. Once we add NAT rules,
